==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGroupingExpressionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingExpressionDescriptionMetadata } from "./WebGroupingExpressionDescriptionMetadata";
import { WebGroupingExpressionEventArgsDescription } from "./WebGroupingExpressionEventArgsDescription";
/**
 * @hidden
 */
var WebGroupingExpressionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingExpressionEventArgsDescriptionMetadata, _super);
    function WebGroupingExpressionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingExpressionEventArgsDescriptionMetadata.b = function (a) {
        if (WebGroupingExpressionEventArgsDescriptionMetadata.a == null) {
            WebGroupingExpressionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingExpressionEventArgsDescriptionMetadata.c(WebGroupingExpressionEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebGroupingExpressionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupingExpressionEventArgsDescriptionMetadata.a);
        WebGroupingExpressionDescriptionMetadata.d(a);
    };
    WebGroupingExpressionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupingExpressionEventArgs");
        a.item("Detail", "Array:WebGroupingExpressionDescription:GroupingExpression");
    };
    WebGroupingExpressionEventArgsDescriptionMetadata.d = function (a) {
        WebGroupingExpressionEventArgsDescriptionMetadata.b(a);
        a.aa("WebGroupingExpressionEventArgs", function () { return new WebGroupingExpressionEventArgsDescription(); });
        a.z("WebGroupingExpressionEventArgs", WebGroupingExpressionEventArgsDescriptionMetadata.a);
    };
    WebGroupingExpressionEventArgsDescriptionMetadata.$t = markType(WebGroupingExpressionEventArgsDescriptionMetadata, 'WebGroupingExpressionEventArgsDescriptionMetadata');
    WebGroupingExpressionEventArgsDescriptionMetadata.a = null;
    return WebGroupingExpressionEventArgsDescriptionMetadata;
}(Base));
export { WebGroupingExpressionEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGroupingExpressionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupingExpressionDescriptionMetadata } from "./WebGroupingExpressionDescriptionMetadata";
import { WebGroupingExpressionEventArgsDescription } from "./WebGroupingExpressionEventArgsDescription";
/**
 * @hidden
 */
var WebGroupingExpressionEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingExpressionEventArgsDescriptionMetadata, _super);
    function WebGroupingExpressionEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupingExpressionEventArgsDescriptionMetadata.b = function (a) {
        if (WebGroupingExpressionEventArgsDescriptionMetadata.a == null) {
            WebGroupingExpressionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupingExpressionEventArgsDescriptionMetadata.c(WebGroupingExpressionEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebGroupingExpressionEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupingExpressionEventArgsDescriptionMetadata.a);
        WebGroupingExpressionDescriptionMetadata.d(a);
    };
    WebGroupingExpressionEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupingExpressionEventArgs");
        a.item("Detail", "Array:WebGroupingExpressionDescription:GroupingExpression");
    };
    WebGroupingExpressionEventArgsDescriptionMetadata.d = function (a) {
        WebGroupingExpressionEventArgsDescriptionMetadata.b(a);
        a.ac("WebGroupingExpressionEventArgs", function () { return new WebGroupingExpressionEventArgsDescription(); });
        a.ab("WebGroupingExpressionEventArgs", WebGroupingExpressionEventArgsDescriptionMetadata.a);
    };
    WebGroupingExpressionEventArgsDescriptionMetadata.$t = markType(WebGroupingExpressionEventArgsDescriptionMetadata, 'WebGroupingExpressionEventArgsDescriptionMetadata');
    WebGroupingExpressionEventArgsDescriptionMetadata.a = null;
    return WebGroupingExpressionEventArgsDescriptionMetadata;
}(Base));
export { WebGroupingExpressionEventArgsDescriptionMetadata };
